












/*----------------------------------------------------------------------- 
 * 
 * File Name: CDestroyVector.c
 * 
 * Author: Finn, L. S.
 * 
 * Revision: $Id: DestroyVector.m4,v 1.1 2000/02/16 01:58:27 jolien Exp $
 * 
 *----------------------------------------------------------------------- 
 * 
 * NAME 
 * CDestroyVector
 * 
 * SYNOPSIS 
 * INT4 CDestroyVector ( Status *,  COMPLEX8Vector **vector );
 * 
 * DESCRIPTION 
 * Returns to system storage allocated by CCreateVector
 * 
 * DIAGNOSTICS 
 * vector == NULL, *vector == NULL, (*vector)->data == NULL, free failure
 *
 * CALLS
 * LALFree
 * 
 * NOTES
 * 
 *-----------------------------------------------------------------------
 */

#ifndef _LALSTDLIB_H
#include "LALStdlib.h"
#ifndef _LALSTDLIB_H
#define _LALSTDLIB_H
#endif
#endif

#ifndef _AVFACTORIES_H
#include "AVFactories.h"
#ifndef _AVFACTORIES_H
#define _AVFACTORIES_H
#endif
#endif

NRCSID (DESTROYVECTORC, "$Id: DestroyVector.m4,v 1.1 2000/02/16 01:58:27 jolien Exp $");

typedef COMPLEX8 dtype;		/* change for different factory */
typedef COMPLEX8Vector vtype;		/* change for different factory */

void CDestroyVector (Status *status, vtype **vector)
{
  /* 
   * Initialize status
   */

  INITSTATUS (status, DESTROYVECTORC);	
      
  /* 
   * Check vector: is it non-NULL?
   */

  ASSERT (vector != NULL, status, DESTROYVECTOR_EVPTR, DESTROYVECTOR_MSGEVPTR);

  /* 
   * Check vector: does it point to non-NULL?
   */

  ASSERT (*vector != NULL, status, DESTROYVECTOR_EUPTR, DESTROYVECTOR_MSGEUPTR);

  /*
   * Check data in vector: does it point to non-NULL
   */

  ASSERT ((*vector)->data != NULL, status,
          DESTROYVECTOR_EDPTR, DESTROYVECTOR_MSGEDPTR);

  /* Ok, now let's free allocated storage */

  LALFree ( (*vector)->data ); /* free allocated data */
  LALFree ( *vector );	/* free vector struct itself */

  *vector = NULL;		/* make sure we don't point to freed struct */

  RETURN (status);
}
