












/*----------------------------------------------------------------------- 
 * 
 * File Name: SDestroyVectorSequence.c
 * 
 * Author: Finn, L. S.
 * 
 * Revision: $Id: DestroyVectorSequence.m4,v 1.1 2000/02/16 01:58:27 jolien Exp $
 * 
 *----------------------------------------------------------------------- 
 * 
 * NAME 
 * SDestroyVectorSequence
 * 
 * SYNOPSIS 
 * void SDestroyVectorSequence ( Status *,  REAL4VectorSequence **vseq );
 * 
 * DESCRIPTION 
 * Returns to system storage allocated by SCreateVectorSequence
 * 
 * DIAGNOSTICS 
 * vseq == NULL, *vseq == NULL, (*vseq)->data == NULL, free failure
 *
 * CALLS
 * LALFree
 * 
 * NOTES
 * 
 *-----------------------------------------------------------------------
 */

#ifndef _LALSTDLIB_H
#include "LALStdlib.h"
#ifndef _LALSTDLIB_H
#define _LALSTDLIB_H
#endif
#endif

#ifndef _SEQFACTORIES_H
#include "SeqFactories.h"
#ifndef _SEQFACTORIES_H
#define _SEQFACTORIES_H
#endif
#endif

NRCSID (DESTROYVECTORSEQUENCEC, "$Id: DestroyVectorSequence.m4,v 1.1 2000/02/16 01:58:27 jolien Exp $");

typedef REAL4 dtype;		/* change for different factory */
typedef REAL4VectorSequence stype;		/* change for different factory */

void SDestroyVectorSequence (Status *status, stype **vseq)
{
  /* 
   * Initialize status
   */

  INITSTATUS (status, DESTROYVECTORSEQUENCEC);
      
  /* 
   * Check vseq: is it non-NULL?
   */

  ASSERT (vseq != NULL, status, DESTROYVECSEQ_EVPTR, DESTROYVECSEQ_MSGEVPTR); 

  /* 
   * Check vseq: does it point to non-NULL?
   */

  ASSERT (*vseq != NULL,status, DESTROYVECSEQ_EUPTR, DESTROYVECSEQ_MSGEUPTR);

  /*
   * Check data in vseq: does it point to non-NULL?
   */

  ASSERT ((*vseq)->data != NULL, status,
          DESTROYVECSEQ_EDPTR, DESTROYVECSEQ_MSGEDPTR);

  /* Ok, now let's free allocated storage */

  LALFree ( (*vseq)->data ); /* free allocated data */
  LALFree ( *vseq );	      /* free vseq struct itself */

  *vseq = NULL;		/* make sure we don't point to freed struct */

  RETURN (status);
}
